﻿using System;
using System.Diagnostics;
using System.IO;
using System.Linq;
using System.Reflection;
using Loader;

namespace Aio1Ef.Packer.Common.Coders
{
    internal static class LoaderConfigCoder
    {
        public static string GenerateResult(Assembly targetAssembly, PackedFileEntry[] packedFiles, int packageLength, string compressLibraryResourceName, Func<byte[], byte[]> decompressMetohd, Func<byte[], byte[]> compressLibraryResourceDecompressMethod, bool sta = false)
        {
            Debug.Assert(targetAssembly.EntryPoint != null, "targetAssembly.EntryPoint != null");

            var coder = new ConfigCoder(Properties.Resources.Loader_Config);
            coder["PackageLength"] = packageLength.ToString();
            coder["TargetAssemblyName"] = targetAssembly.FullName;
            coder["TargetFileName"] = Path.GetFileName(targetAssembly.Location);
            coder["PackedFileEntries"] =
                Environment.NewLine +
                string.Join(",", packedFiles.Select(p => p.ToString()).ToArray());

            if (sta)
                coder["STA"] = "\r\n[System.STAThread]";

            if (decompressMetohd != null)
            {
                coder["Decompress"] = decompressMetohd.Method.Name;
            }

            if (compressLibraryResourceName != null)
            {
                coder["CompressLibrary"] = "GetResource(\"" + compressLibraryResourceName + "\")";
                if (compressLibraryResourceDecompressMethod != null)
                {
                    coder["CompressLibrary"] += "." + compressLibraryResourceDecompressMethod.Method.Name + "()";
                }
            }
            else
            {
                coder["CompressLibrary"] = "null";
            }

            return coder.GenerateResult();
        }
    }
}